/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIPref.idl
 */

#ifndef __gen_nsIPref_h__
#define __gen_nsIPref_h__

#include "nsISupports.h"
#include "nsILocalFile.h"

#include "jsapi.h"
typedef int (*PR_CALLBACK PrefChangedFunc)(const char *, void *);
typedef void (*PrefEnumerationFunc)(const char *, void *);
 
#define NS_PREF_CID                                    \
  { /* {dc26e0e0-ca94-11d1-a9a4-00805f8a7ac4} */       \
    0xdc26e0e0,                                        \
    0xca94,                                            \
    0x11d1,                                            \
    { 0xa9, 0xa4, 0x00, 0x80, 0x5f, 0x8a, 0x7a, 0xc4 } \
  }
#define NS_PREF_CONTRACTID \
  "@mozilla.org/preferences;1" 
#define NS_PREF_CLASSNAME "Preferences Service"
 
#define NS_PREF_VALUE_CHANGED 1 
class nsIFileSpec; /* forward declaration */


/* starting interface:    nsIPref */
#define NS_IPREF_IID_STR "a22ad7b0-ca86-11d1-a9a4-00805f8a7ac4"

#define NS_IPREF_IID \
  {0xa22ad7b0, 0xca86, 0x11d1, \
    { 0xa9, 0xa4, 0x00, 0x80, 0x5f, 0x8a, 0x7a, 0xc4 }}

class NS_NO_VTABLE nsIPref : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IPREF_IID)

  enum { ePrefInvalid = 0 };

  enum { ePrefLocked = 1 };

  enum { ePrefUserset = 2 };

  enum { ePrefConfig = 4 };

  enum { ePrefRemote = 8 };

  enum { ePrefLilocal = 16 };

  enum { ePrefString = 32 };

  enum { ePrefInt = 64 };

  enum { ePrefBool = 128 };

  enum { ePrefValuetypeMask = 224 };

  /* void StartUp (); */
  NS_IMETHOD StartUp(void) = 0;

  /* void ReadUserPrefs (); */
  NS_IMETHOD ReadUserPrefs(void) = 0;

  /* void ReadUserPrefsFrom (in nsIFileSpec spec); */
  NS_IMETHOD ReadUserPrefsFrom(nsIFileSpec *spec) = 0;

  /* void ResetPrefs (); */
  NS_IMETHOD ResetPrefs(void) = 0;

  /* void ShutDown (); */
  NS_IMETHOD ShutDown(void) = 0;

  /* void ReadUserJSFile (in nsIFileSpec filename); */
  NS_IMETHOD ReadUserJSFile(nsIFileSpec *filename) = 0;

  /* void SavePrefFileAs (in nsIFileSpec filename); */
  NS_IMETHOD SavePrefFileAs(nsIFileSpec *filename) = 0;

  /* long GetPrefType (in string pref); */
  NS_IMETHOD GetPrefType(const char *pref, PRInt32 *_retval) = 0;

  /* long GetIntPref (in string pref); */
  NS_IMETHOD GetIntPref(const char *pref, PRInt32 *_retval) = 0;

  /* boolean GetBoolPref (in string pref); */
  NS_IMETHOD GetBoolPref(const char *pref, PRBool *_retval) = 0;

  /* [noscript] void GetBinaryPref (in string pref, in voidPtr buf, inout long buf_length); */
  NS_IMETHOD GetBinaryPref(const char *pref, void * buf, PRInt32 *buf_length) = 0;

  /* unsigned long GetColorPrefDWord (in string pref); */
  NS_IMETHOD GetColorPrefDWord(const char *pref, PRUint32 *_retval) = 0;

  /* void SetCharPref (in string pref, in string value); */
  NS_IMETHOD SetCharPref(const char *pref, const char *value) = 0;

  /* void SetUnicharPref (in string pref, in wstring value); */
  NS_IMETHOD SetUnicharPref(const char *pref, const PRUnichar *value) = 0;

  /* void SetIntPref (in string pref, in long value); */
  NS_IMETHOD SetIntPref(const char *pref, PRInt32 value) = 0;

  /* void SetBoolPref (in string pref, in boolean value); */
  NS_IMETHOD SetBoolPref(const char *pref, PRBool value) = 0;

  /* [noscript] void SetBinaryPref (in string pref, in voidPtr value, in unsigned long size); */
  NS_IMETHOD SetBinaryPref(const char *pref, void * value, PRUint32 size) = 0;

  /* void ClearUserPref (in string pref_name); */
  NS_IMETHOD ClearUserPref(const char *pref_name) = 0;

  /* long GetDefaultIntPref (in string pref); */
  NS_IMETHOD GetDefaultIntPref(const char *pref, PRInt32 *_retval) = 0;

  /* boolean GetDefaultBoolPref (in string pref); */
  NS_IMETHOD GetDefaultBoolPref(const char *pref, PRBool *_retval) = 0;

  /* [noscript] void GetDefaultBinaryPref (in string pref, in voidPtr value, out long length); */
  NS_IMETHOD GetDefaultBinaryPref(const char *pref, void * value, PRInt32 *length) = 0;

  /* void SetDefaultCharPref (in string pref, in string value); */
  NS_IMETHOD SetDefaultCharPref(const char *pref, const char *value) = 0;

  /* void SetDefaultUnicharPref (in string pref, in wstring value); */
  NS_IMETHOD SetDefaultUnicharPref(const char *pref, const PRUnichar *value) = 0;

  /* void SetDefaultIntPref (in string pref, in long value); */
  NS_IMETHOD SetDefaultIntPref(const char *pref, PRInt32 value) = 0;

  /* void SetDefaultBoolPref (in string pref, in boolean value); */
  NS_IMETHOD SetDefaultBoolPref(const char *pref, PRBool value) = 0;

  /* [noscript] void SetDefaultBinaryPref (in string pref, in voidPtr value, in unsigned long size); */
  NS_IMETHOD SetDefaultBinaryPref(const char *pref, void * value, PRUint32 size) = 0;

  /* string CopyCharPref (in string pref); */
  NS_IMETHOD CopyCharPref(const char *pref, char **_retval) = 0;

  /* wstring CopyUnicharPref (in string pref); */
  NS_IMETHOD CopyUnicharPref(const char *pref, PRUnichar **_retval) = 0;

  /* [noscript] voidPtr CopyBinaryPref (in string pref, out long size); */
  NS_IMETHOD CopyBinaryPref(const char *pref, PRInt32 *size, void * *_retval) = 0;

  /* wstring getLocalizedUnicharPref (in string pref); */
  NS_IMETHOD GetLocalizedUnicharPref(const char *pref, PRUnichar **_retval) = 0;

  /* string CopyDefaultCharPref (in string pref); */
  NS_IMETHOD CopyDefaultCharPref(const char *pref, char **_retval) = 0;

  /* wstring CopyDefaultUnicharPref (in string pref); */
  NS_IMETHOD CopyDefaultUnicharPref(const char *pref, PRUnichar **_retval) = 0;

  /* [noscript] voidPtr CopyDefaultBinaryPref (in string pref, out long size); */
  NS_IMETHOD CopyDefaultBinaryPref(const char *pref, PRInt32 *size, void * *_retval) = 0;

  /* nsIFileSpec GetFilePref (in string pref); */
  NS_IMETHOD GetFilePref(const char *pref, nsIFileSpec **_retval) = 0;

  /* void SetFilePref (in string pref, in nsIFileSpec value, in boolean setDefault); */
  NS_IMETHOD SetFilePref(const char *pref, nsIFileSpec *value, PRBool setDefault) = 0;

  /* nsILocalFile getFileXPref (in string pref); */
  NS_IMETHOD GetFileXPref(const char *pref, nsILocalFile **_retval) = 0;

  /* void setFileXPref (in string pref, in nsILocalFile value); */
  NS_IMETHOD SetFileXPref(const char *pref, nsILocalFile *value) = 0;

  /* boolean PrefIsLocked (in string pref); */
  NS_IMETHOD PrefIsLocked(const char *pref, PRBool *_retval) = 0;

  /* void SavePrefFile (); */
  NS_IMETHOD SavePrefFile(void) = 0;

  /* [noscript] void RegisterCallback (in string domain, in PrefChangedFunc callback, in voidPtr closure); */
  NS_IMETHOD RegisterCallback(const char *domain, PrefChangedFunc callback, void * closure) = 0;

  /* [noscript] void UnregisterCallback (in string domain, in PrefChangedFunc callback, in voidPtr closure); */
  NS_IMETHOD UnregisterCallback(const char *domain, PrefChangedFunc callback, void * closure) = 0;

  /* void DeleteBranch (in string branchName); */
  NS_IMETHOD DeleteBranch(const char *branchName) = 0;

  /* void CreateChildList (in string parent_node, out string childList); */
  NS_IMETHOD CreateChildList(const char *parent_node, char **childList) = 0;

  /* [noscript] string NextChild (in string child_list, inout short index); */
  NS_IMETHOD NextChild(const char *child_list, PRInt16 *index, char **_retval) = 0;

  /**
   * EnumerateChildren
   *
   * Call back function "callback" with every preference string
   * having prefix "parent". Pass "data" to "callback" when calling.
   * 
   * @param parent A string representation of a prefix of preferences
   * @param callback A function to call back for each matching preference
   * @param data A piece of data to pass on to the callback
   */
  /* [noscript] void EnumerateChildren (in string parent, in PrefEnumerationFunc callback, in voidPtr data); */
  NS_IMETHOD EnumerateChildren(const char *parent, PrefEnumerationFunc callback, void * data) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPREF \
  NS_IMETHOD StartUp(void); \
  NS_IMETHOD ReadUserPrefs(void); \
  NS_IMETHOD ReadUserPrefsFrom(nsIFileSpec *spec); \
  NS_IMETHOD ResetPrefs(void); \
  NS_IMETHOD ShutDown(void); \
  NS_IMETHOD ReadUserJSFile(nsIFileSpec *filename); \
  NS_IMETHOD SavePrefFileAs(nsIFileSpec *filename); \
  NS_IMETHOD GetPrefType(const char *pref, PRInt32 *_retval); \
  NS_IMETHOD GetIntPref(const char *pref, PRInt32 *_retval); \
  NS_IMETHOD GetBoolPref(const char *pref, PRBool *_retval); \
  NS_IMETHOD GetBinaryPref(const char *pref, void * buf, PRInt32 *buf_length); \
  NS_IMETHOD GetColorPrefDWord(const char *pref, PRUint32 *_retval); \
  NS_IMETHOD SetCharPref(const char *pref, const char *value); \
  NS_IMETHOD SetUnicharPref(const char *pref, const PRUnichar *value); \
  NS_IMETHOD SetIntPref(const char *pref, PRInt32 value); \
  NS_IMETHOD SetBoolPref(const char *pref, PRBool value); \
  NS_IMETHOD SetBinaryPref(const char *pref, void * value, PRUint32 size); \
  NS_IMETHOD ClearUserPref(const char *pref_name); \
  NS_IMETHOD GetDefaultIntPref(const char *pref, PRInt32 *_retval); \
  NS_IMETHOD GetDefaultBoolPref(const char *pref, PRBool *_retval); \
  NS_IMETHOD GetDefaultBinaryPref(const char *pref, void * value, PRInt32 *length); \
  NS_IMETHOD SetDefaultCharPref(const char *pref, const char *value); \
  NS_IMETHOD SetDefaultUnicharPref(const char *pref, const PRUnichar *value); \
  NS_IMETHOD SetDefaultIntPref(const char *pref, PRInt32 value); \
  NS_IMETHOD SetDefaultBoolPref(const char *pref, PRBool value); \
  NS_IMETHOD SetDefaultBinaryPref(const char *pref, void * value, PRUint32 size); \
  NS_IMETHOD CopyCharPref(const char *pref, char **_retval); \
  NS_IMETHOD CopyUnicharPref(const char *pref, PRUnichar **_retval); \
  NS_IMETHOD CopyBinaryPref(const char *pref, PRInt32 *size, void * *_retval); \
  NS_IMETHOD GetLocalizedUnicharPref(const char *pref, PRUnichar **_retval); \
  NS_IMETHOD CopyDefaultCharPref(const char *pref, char **_retval); \
  NS_IMETHOD CopyDefaultUnicharPref(const char *pref, PRUnichar **_retval); \
  NS_IMETHOD CopyDefaultBinaryPref(const char *pref, PRInt32 *size, void * *_retval); \
  NS_IMETHOD GetFilePref(const char *pref, nsIFileSpec **_retval); \
  NS_IMETHOD SetFilePref(const char *pref, nsIFileSpec *value, PRBool setDefault); \
  NS_IMETHOD GetFileXPref(const char *pref, nsILocalFile **_retval); \
  NS_IMETHOD SetFileXPref(const char *pref, nsILocalFile *value); \
  NS_IMETHOD PrefIsLocked(const char *pref, PRBool *_retval); \
  NS_IMETHOD SavePrefFile(void); \
  NS_IMETHOD RegisterCallback(const char *domain, PrefChangedFunc callback, void * closure); \
  NS_IMETHOD UnregisterCallback(const char *domain, PrefChangedFunc callback, void * closure); \
  NS_IMETHOD DeleteBranch(const char *branchName); \
  NS_IMETHOD CreateChildList(const char *parent_node, char **childList); \
  NS_IMETHOD NextChild(const char *child_list, PRInt16 *index, char **_retval); \
  NS_IMETHOD EnumerateChildren(const char *parent, PrefEnumerationFunc callback, void * data); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPREF(_to) \
  NS_IMETHOD StartUp(void) { return _to ## StartUp(); } \
  NS_IMETHOD ReadUserPrefs(void) { return _to ## ReadUserPrefs(); } \
  NS_IMETHOD ReadUserPrefsFrom(nsIFileSpec *spec) { return _to ## ReadUserPrefsFrom(spec); } \
  NS_IMETHOD ResetPrefs(void) { return _to ## ResetPrefs(); } \
  NS_IMETHOD ShutDown(void) { return _to ## ShutDown(); } \
  NS_IMETHOD ReadUserJSFile(nsIFileSpec *filename) { return _to ## ReadUserJSFile(filename); } \
  NS_IMETHOD SavePrefFileAs(nsIFileSpec *filename) { return _to ## SavePrefFileAs(filename); } \
  NS_IMETHOD GetPrefType(const char *pref, PRInt32 *_retval) { return _to ## GetPrefType(pref, _retval); } \
  NS_IMETHOD GetIntPref(const char *pref, PRInt32 *_retval) { return _to ## GetIntPref(pref, _retval); } \
  NS_IMETHOD GetBoolPref(const char *pref, PRBool *_retval) { return _to ## GetBoolPref(pref, _retval); } \
  NS_IMETHOD GetBinaryPref(const char *pref, void * buf, PRInt32 *buf_length) { return _to ## GetBinaryPref(pref, buf, buf_length); } \
  NS_IMETHOD GetColorPrefDWord(const char *pref, PRUint32 *_retval) { return _to ## GetColorPrefDWord(pref, _retval); } \
  NS_IMETHOD SetCharPref(const char *pref, const char *value) { return _to ## SetCharPref(pref, value); } \
  NS_IMETHOD SetUnicharPref(const char *pref, const PRUnichar *value) { return _to ## SetUnicharPref(pref, value); } \
  NS_IMETHOD SetIntPref(const char *pref, PRInt32 value) { return _to ## SetIntPref(pref, value); } \
  NS_IMETHOD SetBoolPref(const char *pref, PRBool value) { return _to ## SetBoolPref(pref, value); } \
  NS_IMETHOD SetBinaryPref(const char *pref, void * value, PRUint32 size) { return _to ## SetBinaryPref(pref, value, size); } \
  NS_IMETHOD ClearUserPref(const char *pref_name) { return _to ## ClearUserPref(pref_name); } \
  NS_IMETHOD GetDefaultIntPref(const char *pref, PRInt32 *_retval) { return _to ## GetDefaultIntPref(pref, _retval); } \
  NS_IMETHOD GetDefaultBoolPref(const char *pref, PRBool *_retval) { return _to ## GetDefaultBoolPref(pref, _retval); } \
  NS_IMETHOD GetDefaultBinaryPref(const char *pref, void * value, PRInt32 *length) { return _to ## GetDefaultBinaryPref(pref, value, length); } \
  NS_IMETHOD SetDefaultCharPref(const char *pref, const char *value) { return _to ## SetDefaultCharPref(pref, value); } \
  NS_IMETHOD SetDefaultUnicharPref(const char *pref, const PRUnichar *value) { return _to ## SetDefaultUnicharPref(pref, value); } \
  NS_IMETHOD SetDefaultIntPref(const char *pref, PRInt32 value) { return _to ## SetDefaultIntPref(pref, value); } \
  NS_IMETHOD SetDefaultBoolPref(const char *pref, PRBool value) { return _to ## SetDefaultBoolPref(pref, value); } \
  NS_IMETHOD SetDefaultBinaryPref(const char *pref, void * value, PRUint32 size) { return _to ## SetDefaultBinaryPref(pref, value, size); } \
  NS_IMETHOD CopyCharPref(const char *pref, char **_retval) { return _to ## CopyCharPref(pref, _retval); } \
  NS_IMETHOD CopyUnicharPref(const char *pref, PRUnichar **_retval) { return _to ## CopyUnicharPref(pref, _retval); } \
  NS_IMETHOD CopyBinaryPref(const char *pref, PRInt32 *size, void * *_retval) { return _to ## CopyBinaryPref(pref, size, _retval); } \
  NS_IMETHOD GetLocalizedUnicharPref(const char *pref, PRUnichar **_retval) { return _to ## GetLocalizedUnicharPref(pref, _retval); } \
  NS_IMETHOD CopyDefaultCharPref(const char *pref, char **_retval) { return _to ## CopyDefaultCharPref(pref, _retval); } \
  NS_IMETHOD CopyDefaultUnicharPref(const char *pref, PRUnichar **_retval) { return _to ## CopyDefaultUnicharPref(pref, _retval); } \
  NS_IMETHOD CopyDefaultBinaryPref(const char *pref, PRInt32 *size, void * *_retval) { return _to ## CopyDefaultBinaryPref(pref, size, _retval); } \
  NS_IMETHOD GetFilePref(const char *pref, nsIFileSpec **_retval) { return _to ## GetFilePref(pref, _retval); } \
  NS_IMETHOD SetFilePref(const char *pref, nsIFileSpec *value, PRBool setDefault) { return _to ## SetFilePref(pref, value, setDefault); } \
  NS_IMETHOD GetFileXPref(const char *pref, nsILocalFile **_retval) { return _to ## GetFileXPref(pref, _retval); } \
  NS_IMETHOD SetFileXPref(const char *pref, nsILocalFile *value) { return _to ## SetFileXPref(pref, value); } \
  NS_IMETHOD PrefIsLocked(const char *pref, PRBool *_retval) { return _to ## PrefIsLocked(pref, _retval); } \
  NS_IMETHOD SavePrefFile(void) { return _to ## SavePrefFile(); } \
  NS_IMETHOD RegisterCallback(const char *domain, PrefChangedFunc callback, void * closure) { return _to ## RegisterCallback(domain, callback, closure); } \
  NS_IMETHOD UnregisterCallback(const char *domain, PrefChangedFunc callback, void * closure) { return _to ## UnregisterCallback(domain, callback, closure); } \
  NS_IMETHOD DeleteBranch(const char *branchName) { return _to ## DeleteBranch(branchName); } \
  NS_IMETHOD CreateChildList(const char *parent_node, char **childList) { return _to ## CreateChildList(parent_node, childList); } \
  NS_IMETHOD NextChild(const char *child_list, PRInt16 *index, char **_retval) { return _to ## NextChild(child_list, index, _retval); } \
  NS_IMETHOD EnumerateChildren(const char *parent, PrefEnumerationFunc callback, void * data) { return _to ## EnumerateChildren(parent, callback, data); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPref : public nsIPref
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPREF

  nsPref();
  virtual ~nsPref();
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPref, nsIPref)

nsPref::nsPref()
{
  NS_INIT_ISUPPORTS();
  /* member initializers and constructor code */
}

nsPref::~nsPref()
{
  /* destructor code */
}

/* void StartUp (); */
NS_IMETHODIMP nsPref::StartUp()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ReadUserPrefs (); */
NS_IMETHODIMP nsPref::ReadUserPrefs()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ReadUserPrefsFrom (in nsIFileSpec spec); */
NS_IMETHODIMP nsPref::ReadUserPrefsFrom(nsIFileSpec *spec)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ResetPrefs (); */
NS_IMETHODIMP nsPref::ResetPrefs()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ShutDown (); */
NS_IMETHODIMP nsPref::ShutDown()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ReadUserJSFile (in nsIFileSpec filename); */
NS_IMETHODIMP nsPref::ReadUserJSFile(nsIFileSpec *filename)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SavePrefFileAs (in nsIFileSpec filename); */
NS_IMETHODIMP nsPref::SavePrefFileAs(nsIFileSpec *filename)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long GetPrefType (in string pref); */
NS_IMETHODIMP nsPref::GetPrefType(const char *pref, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long GetIntPref (in string pref); */
NS_IMETHODIMP nsPref::GetIntPref(const char *pref, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean GetBoolPref (in string pref); */
NS_IMETHODIMP nsPref::GetBoolPref(const char *pref, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void GetBinaryPref (in string pref, in voidPtr buf, inout long buf_length); */
NS_IMETHODIMP nsPref::GetBinaryPref(const char *pref, void * buf, PRInt32 *buf_length)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long GetColorPrefDWord (in string pref); */
NS_IMETHODIMP nsPref::GetColorPrefDWord(const char *pref, PRUint32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetCharPref (in string pref, in string value); */
NS_IMETHODIMP nsPref::SetCharPref(const char *pref, const char *value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetUnicharPref (in string pref, in wstring value); */
NS_IMETHODIMP nsPref::SetUnicharPref(const char *pref, const PRUnichar *value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetIntPref (in string pref, in long value); */
NS_IMETHODIMP nsPref::SetIntPref(const char *pref, PRInt32 value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetBoolPref (in string pref, in boolean value); */
NS_IMETHODIMP nsPref::SetBoolPref(const char *pref, PRBool value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void SetBinaryPref (in string pref, in voidPtr value, in unsigned long size); */
NS_IMETHODIMP nsPref::SetBinaryPref(const char *pref, void * value, PRUint32 size)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ClearUserPref (in string pref_name); */
NS_IMETHODIMP nsPref::ClearUserPref(const char *pref_name)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long GetDefaultIntPref (in string pref); */
NS_IMETHODIMP nsPref::GetDefaultIntPref(const char *pref, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean GetDefaultBoolPref (in string pref); */
NS_IMETHODIMP nsPref::GetDefaultBoolPref(const char *pref, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void GetDefaultBinaryPref (in string pref, in voidPtr value, out long length); */
NS_IMETHODIMP nsPref::GetDefaultBinaryPref(const char *pref, void * value, PRInt32 *length)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetDefaultCharPref (in string pref, in string value); */
NS_IMETHODIMP nsPref::SetDefaultCharPref(const char *pref, const char *value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetDefaultUnicharPref (in string pref, in wstring value); */
NS_IMETHODIMP nsPref::SetDefaultUnicharPref(const char *pref, const PRUnichar *value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetDefaultIntPref (in string pref, in long value); */
NS_IMETHODIMP nsPref::SetDefaultIntPref(const char *pref, PRInt32 value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetDefaultBoolPref (in string pref, in boolean value); */
NS_IMETHODIMP nsPref::SetDefaultBoolPref(const char *pref, PRBool value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void SetDefaultBinaryPref (in string pref, in voidPtr value, in unsigned long size); */
NS_IMETHODIMP nsPref::SetDefaultBinaryPref(const char *pref, void * value, PRUint32 size)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string CopyCharPref (in string pref); */
NS_IMETHODIMP nsPref::CopyCharPref(const char *pref, char **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring CopyUnicharPref (in string pref); */
NS_IMETHODIMP nsPref::CopyUnicharPref(const char *pref, PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] voidPtr CopyBinaryPref (in string pref, out long size); */
NS_IMETHODIMP nsPref::CopyBinaryPref(const char *pref, PRInt32 *size, void * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring getLocalizedUnicharPref (in string pref); */
NS_IMETHODIMP nsPref::GetLocalizedUnicharPref(const char *pref, PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string CopyDefaultCharPref (in string pref); */
NS_IMETHODIMP nsPref::CopyDefaultCharPref(const char *pref, char **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring CopyDefaultUnicharPref (in string pref); */
NS_IMETHODIMP nsPref::CopyDefaultUnicharPref(const char *pref, PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] voidPtr CopyDefaultBinaryPref (in string pref, out long size); */
NS_IMETHODIMP nsPref::CopyDefaultBinaryPref(const char *pref, PRInt32 *size, void * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIFileSpec GetFilePref (in string pref); */
NS_IMETHODIMP nsPref::GetFilePref(const char *pref, nsIFileSpec **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetFilePref (in string pref, in nsIFileSpec value, in boolean setDefault); */
NS_IMETHODIMP nsPref::SetFilePref(const char *pref, nsIFileSpec *value, PRBool setDefault)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsILocalFile getFileXPref (in string pref); */
NS_IMETHODIMP nsPref::GetFileXPref(const char *pref, nsILocalFile **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setFileXPref (in string pref, in nsILocalFile value); */
NS_IMETHODIMP nsPref::SetFileXPref(const char *pref, nsILocalFile *value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean PrefIsLocked (in string pref); */
NS_IMETHODIMP nsPref::PrefIsLocked(const char *pref, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SavePrefFile (); */
NS_IMETHODIMP nsPref::SavePrefFile()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void RegisterCallback (in string domain, in PrefChangedFunc callback, in voidPtr closure); */
NS_IMETHODIMP nsPref::RegisterCallback(const char *domain, PrefChangedFunc callback, void * closure)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void UnregisterCallback (in string domain, in PrefChangedFunc callback, in voidPtr closure); */
NS_IMETHODIMP nsPref::UnregisterCallback(const char *domain, PrefChangedFunc callback, void * closure)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void DeleteBranch (in string branchName); */
NS_IMETHODIMP nsPref::DeleteBranch(const char *branchName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void CreateChildList (in string parent_node, out string childList); */
NS_IMETHODIMP nsPref::CreateChildList(const char *parent_node, char **childList)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] string NextChild (in string child_list, inout short index); */
NS_IMETHODIMP nsPref::NextChild(const char *child_list, PRInt16 *index, char **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void EnumerateChildren (in string parent, in PrefEnumerationFunc callback, in voidPtr data); */
NS_IMETHODIMP nsPref::EnumerateChildren(const char *parent, PrefEnumerationFunc callback, void * data)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIPref_h__ */
